pub struct Input {
pub graph: FHIRUri,
}Fields
graph: FHIRUriServers MAY choose to allow any graph definition to be specified, but MAY require that the client choose a graph definition from a specific list of known supported definitions. The server is not required to support a formal definition of the graph on the end point